@@ -140,11 +140,13 @@ class ScannerBase(abc.ABC):  # pylint: disable=too-many-instance-attributes
     _included_paths: Optional[List[Pattern]] = None
     _excluded_paths: Optional[List[Pattern]] = None
     _excluded_entropy: Optional[List[Rule]] = None
+    _excluded_regex: Optional[List[Rule]] = None
     _rules_regexes: Optional[Set[Rule]] = None
     global_options: types.GlobalOptions
     logger: logging.Logger
     _scan_lock: threading.Lock = threading.Lock()
     _excluded_signatures: Optional[Tuple[str, ...]] = None
+    _rule_patterns: Optional[Iterable[Dict[str, str]]] = None
     _config_data: MutableMapping[str, Any] = {}
     _issue_list: List[Issue] = []
     _issue_file: Optional[IO] = None
@@ -157,6 +159,27 @@ class ScannerBase(abc.ABC):  # pylint: disable=too-many-instance-attributes
         self.global_options = options
         self.logger = logging.getLogger(__name__)
 
+    def load_config(self, config_path: str) -> None:
+        """Load 'local' configuration file from target location
+
+        :param config_path: Directory expected to hold configuration file
+        """
+        # Skipping loading default project config if --no-target-config is supplied.
+        if not self.global_options.target_config:
+            return
+        # Look for usable configuration file
+        try:
+            (config_file, data) = config.load_config_from_path(
+                pathlib.Path(config_path)
+            )
+        except (FileNotFoundError, types.ConfigException):
+            # Nothing usable found; nothing to do
+            return
+
+        # Do not reload data if it was already specified using `--config`
+        if config_file.resolve() not in config.REFERENCED_CONFIG_FILES:
+            self.config_data = data
+
     def compute_scaled_entropy_limit(self, maximum_bitrate: float) -> float:
         """Determine low entropy cutoff for specified bitrate
 
@@ -253,12 +276,30 @@ class ScannerBase(abc.ABC):  # pylint: disable=too-many-instance-attributes
             patterns = list(self.global_options.exclude_entropy_patterns or ()) + list(
                 self.config_data.get("exclude_entropy_patterns", ())
             )
-            self._excluded_entropy = config.compile_rules(patterns) if patterns else []
+            self._excluded_entropy = (
+                config.compile_rules(patterns, "entropy") if patterns else []
+            )
             self.logger.debug(
                 "Excluded entropy was initialized as: %s", self._excluded_entropy
             )
         return self._excluded_entropy
 
+    @property
+    def excluded_regex(self) -> List[Rule]:
+        """Get a list of regexes used as an exclusive list of paths to scan."""
+        if self._excluded_regex is None:
+            self.logger.info("Initializing excluded regex patterns")
+            patterns = list(self.global_options.exclude_regex_patterns or ()) + list(
+                self.config_data.get("exclude_regex_patterns", ())
+            )
+            self._excluded_regex = (
+                config.compile_rules(patterns, "regex") if patterns else []
+            )
+            self.logger.debug(
+                "Excluded regex was initialized as: %s", self._excluded_regex
+            )
+        return self._excluded_regex
+
     @property
     def excluded_paths(self) -> List[Pattern]:
         """Get a list of regexes used to match paths to exclude from the scan"""
@@ -293,7 +334,7 @@ class ScannerBase(abc.ABC):  # pylint: disable=too-many-instance-attributes
             try:
                 self._rules_regexes = config.configure_regexes(
                     include_default=self.global_options.default_regexes,
-                    rule_patterns=self.global_options.rule_patterns,
+                    rule_patterns=self.rule_patterns,
                     rules_repo=self.global_options.git_rules_repo,
                     rules_repo_files=self.global_options.git_rules_files,
                 )
@@ -332,6 +373,27 @@ class ScannerBase(abc.ABC):  # pylint: disable=too-many-instance-attributes
             return False
         return True
 
+    @cached_property
+    def rule_patterns(self) -> Optional[Iterable[Dict[str, str]]]:
+        """Get a list of patterns to the to search in the target repository or folder being scanned
+
+        :returns: The regular expression patterns to searched in the target
+        @return:
+        """
+        if self._rule_patterns is None:
+            rules: List[Dict[str, str]] = []
+            for rule in tuple(self.global_options.rule_patterns or []) + tuple(
+                self.config_data.get("rule_patterns", [])
+            ):
+                if isinstance(rule, dict):
+                    rules.append(rule)
+                else:
+                    raise types.ConfigException(
+                        f"{type(rule).__name__} pattern is illegal in rule-patterns"
+                    )
+            self._rule_patterns = rules
+        return self._rule_patterns
+
     @cached_property
     def excluded_signatures(self) -> Tuple[str, ...]:
         """Get a list of the signatures of findings to be excluded from the scan results.
@@ -371,7 +433,7 @@ class ScannerBase(abc.ABC):  # pylint: disable=too-many-instance-attributes
 
     @staticmethod
     @lru_cache(maxsize=None)
-    def rule_matches(rule: Rule, string: str, line: str, path: str) -> bool:
+    def rule_matches(rule: Rule, string: Optional[str], line: str, path: str) -> bool:
         """
         Match string and path against rule.
 
@@ -383,6 +445,8 @@ class ScannerBase(abc.ABC):  # pylint: disable=too-many-instance-attributes
         """
         match = False
         if rule.re_match_scope == Scope.Word:
+            if not string:
+                raise TartufoException(f"String required for {Scope.Word} scope")
             scope = string
         elif rule.re_match_scope == Scope.Line:
             scope = line
@@ -415,6 +479,18 @@ class ScannerBase(abc.ABC):  # pylint: disable=too-many-instance-attributes
             for p in self.excluded_entropy
         )
 
+    def regex_string_is_excluded(self, line: str, path: str) -> bool:
+        """Find whether the signature of some data has been excluded in configuration.
+
+        :param line: Source line containing string of interest
+        :param path: Path to check against rule path pattern
+        :return: True if excluded, False otherwise
+        """
+
+        return bool(self.excluded_regex) and any(
+            ScannerBase.rule_matches(p, None, line, path) for p in self.excluded_regex
+        )
+
     @staticmethod
     @lru_cache(maxsize=None)
     def calculate_entropy(data: str) -> float:
@@ -589,9 +665,14 @@ class ScannerBase(abc.ABC):  # pylint: disable=too-many-instance-attributes
                 for match in found_strings:
                     # Filter out any explicitly "allowed" match signatures
                     if not self.signature_is_excluded(match, chunk.file_path):
-                        issue = Issue(types.IssueType.RegEx, match, chunk)
-                        issue.issue_detail = rule.name
-                        yield issue
+                        if self.regex_string_is_excluded(match, chunk.file_path):
+                            self.logger.debug(
+                                "line containing regex was excluded: %s", match
+                            )
+                        else:
+                            issue = Issue(types.IssueType.RegEx, match, chunk)
+                            issue.issue_detail = rule.name
+                            yield issue
 
     @property
     @abc.abstractmethod
@@ -626,6 +707,12 @@ class GitScanner(ScannerBase, abc.ABC):
         # pygit2 1.9.2 and later) fail in docker context otherwise.
         pygit2.option(pygit2.GIT_OPT_SET_OWNER_VALIDATION, 0)
 
+        # Load any configuration file in the target repository. This comes
+        # *BEFORE* load_repo() because that method may rely on configuration data
+        # existing already (for example, to filter out submodules); it's safe
+        # because the caller will already have populated the local working
+        # directory before initializing this object.
+        self.load_config(self.repo_path)
         self._repo = self.load_repo(self.repo_path)
 
     def _iter_diff_index(
@@ -694,6 +781,10 @@ class GitScanner(ScannerBase, abc.ABC):
                 "A likely cause is that a file tree was committed in place of a "
                 "submodule."
             ) from exc
+
+        # FIXME: This is really sketchy, unless we know configuration already is
+        # complete by the time we do this (which will short-circuit any future
+        # re-evaluation). It happens to work now.
         self._excluded_paths = list(set(self.excluded_paths + patterns))
 
     @abc.abstractmethod
@@ -724,16 +815,6 @@ class GitRepoScanner(GitScanner):
         super().__init__(global_options, repo_path)
 
     def load_repo(self, repo_path: str) -> pygit2.Repository:
-        config_file: Optional[pathlib.Path] = None
-        data: MutableMapping[str, Any] = {}
-        try:
-            (config_file, data) = config.load_config_from_path(
-                pathlib.Path(repo_path), traverse=False
-            )
-        except (FileNotFoundError, types.ConfigException):
-            config_file = None
-        if config_file and str(config_file) != self.global_options.config:
-            self.config_data = data
         try:
             repo = pygit2.Repository(repo_path)
             if not repo.is_bare:
@@ -877,10 +958,13 @@ class GitPreCommitScanner(GitScanner):
         super().__init__(global_options, repo_path)
 
     def load_repo(self, repo_path: str) -> pygit2.Repository:
-        repo = pygit2.Repository(repo_path)
-        if not self._include_submodules:
-            self.filter_submodules(repo)
-        return repo
+        try:
+            repo = pygit2.Repository(repo_path)
+            if not self._include_submodules:
+                self.filter_submodules(repo)
+            return repo
+        except git.GitError as exc:
+            raise types.GitLocalException(str(exc)) from exc
 
     @property
     def chunks(self):
@@ -920,6 +1004,7 @@ class FolderScanner(ScannerBase):
         self.target = target
         self.recurse = recurse
         super().__init__(global_options)
+        self.load_config(self.target)
 
     @property
     def chunks(self) -> Generator[types.Chunk, None, None]:
